@@ -29,7 +29,7 @@ class ObservableListView(PyHtmlView):
         if self.sort_lambda is None:
             return data
         else:
-            return sorted(data, key=lambda x: self.sort_lambda, reverse=self.sort_reverse)
+            return sorted(data, key=self.sort_lambda, reverse=self.sort_reverse)
 
     def set_visible(self, visible):
         if self.is_visible == visible:  # not changed
